import sqlite3

class Database:
    def __init__(self, db_name='db.sqlite'):
        self.connection = sqlite3.connect(db_name, check_same_thread=False)
        self.cursor = self.connection.cursor()
        self.create_snake_table()

    def create_snake_table(self):
        self.cursor.execute('''
            CREATE TABLE IF NOT EXISTS snake (
                id INTEGER PRIMARY KEY AUTOINCREMENT,
                name TEXT NOT NULL,
                score INTEGER NOT NULL
            )
        ''')
        self.connection.commit()

    def insert_snake(self, name, score):
        old_score = self.get_snake_score(name)
        print(f"Old score for {name}: {old_score}")
        print(f"New score for {name}: {score}")
        if old_score is not None and score <= old_score:
            return
        
        self.cursor.execute('''
            INSERT INTO snake (name, score)
            VALUES (?, ?)
        ''', (name, score))
        self.connection.commit()

    def get_snake_score(self, name):
        self.cursor.execute('SELECT score FROM snake WHERE name = ? ORDER BY score DESC LIMIT 1', (name,))
        result = self.cursor.fetchone()
        return result[0] if result else None

    def get_snake_scores(self):
        self.cursor.execute('SELECT * FROM snake ORDER BY score DESC')
        return self.cursor.fetchall()
    
    def close(self):
        self.connection.close()